@@ -119,8 +119,7 @@ extern const unsigned int s390_sframe_cfa_ra_reg;
 #define SFRAME_CFA_RA_REG s390_sframe_cfa_ra_reg
 
 /* Whether SFrame return address tracking is needed.  */
-extern bool s390_sframe_ra_tracking_p (void);
-#define sframe_ra_tracking_p s390_sframe_ra_tracking_p
+#define sframe_ra_tracking_p() true
 
 /* The fixed offset from CFA for SFrame to recover the return address.
    (useful only when SFrame RA tracking is not needed).  */
@@ -132,10 +131,9 @@ unsigned char s390_sframe_get_abi_arch (void);
 #define sframe_get_abi_arch s390_sframe_get_abi_arch
 
 /* Whether SFrame FDE of type SFRAME_FDE_TYPE_FLEX be generated.  */
-extern bool s390_support_flex_fde_p (void);
-#define sframe_support_flex_fde_p s390_support_flex_fde_p
+#define sframe_support_flex_fde_p() true
 
-/* The target supports Object Attributes.  */
-#define TC_OBJ_ATTR 1
+/* The target supports Object Attributes v1.  */
+#define TC_OBJ_ATTR_v1 1
 
 #endif /* TC_S390 */
